==> rflowcyt_1.6.0.tar.gz: rflowcyt/R/plotvar.FCS.R <==
plotvar.FCS <- function(x,
                        varpos,
                        type=c("uni", "bi"),
                        plotType=c("hist", "ContourScatterPlot", "plot"),
                        names.var=NULL,
                        title.pl="",
                        xlimit=NULL,
                        ylimit=NULL,
                        plot.freq=TRUE,
                        color.hist.plot="white",
                        CSPlot=TRUE,
                        hexbin.CSPlot=TRUE,
                        hexbin.style.CSPlot=c("colorscale",
                          "lattice", "centroids",
                          "nested.lattice", "nested.centroids"),
                        n.hexbins.CSPlot=100,
                        x.grid.CSPlot=seq(0, 1025, by=25),
                        y.grid.CSPlot=seq(0, 1025, by=25),
                        image.col.CSPlot=heat.colors(2),
                        numlev.CSPlot=25,
                        xaxt="s",
                        yaxt="s",
                        MY.DEBUG=FALSE, ...) {
  
  ##
  ## input
  ##
  
  ## x    FCS object from read.FCS function
  ## type        type of cut/gating
  ##              uni  univariate graph
  ##              bi bivariate graph
  
  
  ## plotType    default is ContourScatterPlot, but can also be plot, hist, etc.
  ## varpos         the variable column position of the data being examined
  ##                or a vector of column postions
  
  ## names       a character vector of the names of the variables to be plotted
  ##                either one name or two names
  ## title       a string of the title of the graph
  ## xlimit      a vector denoting the range of the x (horizontal) axis
  ## ylimit      a vector denoting the range of the y (vertical) axis
  ## plot.freq   boolean; if true then the frequencies instead of the
  ##                relative frequencies (probabilities) are plotted (only if plotType=hist)
  
  ## CSPlot      a boolean of whether or not this is a ContourScatterPlot
  
  ## xgrid.CSPlot    a sequence denoting the grid marks
  ##                    for the x coordinate (for ContourScatterPlot ONLY!)
  ## ygrid.CSPlot    a sequence denoting the grid marks
  ##                     for the y coordinate (for ContourScatterPlot ONLY!)
  ## image.col.CSPlot  a color for the image (for ContourScatterPlot ONLY!)
  ## numlev.CSplot     number of levels for the ContourScatterPlot
  ## MY.DEBUG         boolean; if true then process statements are printed
  ##
  ## output
  ##
  ## a graph with the gates shown
  
  if (!checkvars(x, MY.DEBUG=MY.DEBUG)){
    x <- fixvars(x, MY.DEBUG=MY.DEBUG)
  }

 
  if (is.null(names.var)==TRUE) {
    names.var <- colnames(x@data)[varpos]
  }
            
  data.kk <- x@data[,varpos]
  ## type <- match.arg(type)
  if (length(varpos) %in% c(1,2)) {
    type <- c("uni", "bi")[length(varpos)]
    
  } else {
    stop("Input 'varpos' can only be of length 1 or 2")
  }
          
          
  plotType <- c("hist", "ContourScatterPlot", "plot")[length(varpos)]
  if (CSPlot==TRUE){
    plotType <- "ContourScatterPlot"
  } else {
    plotType <- "plot"
  }


  plotType <- get(plotType)
  if (type=="uni"){
    
    ##note this is NOT probability Binning, only a regular histogram, prob binning should be done only after gating
    
    
    if (is.null(xlimit)){
      xlimit <- range(data.kk)
    }
    
    if (is.null(ylimit)){
      hist(data.kk, xlab=names.var[1], ylab="frequency",
           main=paste(title.pl, names.var[1], sep=" "),
           freq=plot.freq,
           xlim=xlimit,
           col=color.hist.plot, xaxt=xaxt,
           yaxt=yaxt,...)
    } else {
      hist(data.kk, xlab=names.var[1], ylab="frequency",
           main=paste(title.pl, names.var[1], sep=" "),
           freq=plot.freq,
           xlim=xlimit, ylim=ylimit,
           col=color.hist.plot, xaxt=xaxt,
           yaxt=yaxt,...)
      
      
    }
    
  } else if (type=="bi"){
    if(CSPlot==TRUE){
      if (is.null(x.grid.CSPlot)){
        range.x <- range(data.kk[,1])
        x.grid.CSPlot <- seq(range.x[1],
                             ceiling(diff(range.x)/25)*25+range.x[1],
                             by=25)
      }
      if (is.null(y.grid.CSPlot)){
        range.y <- range(data.kk[,2])
        y.grid.CSPlot <- seq(range.y[1],
                             ceiling(diff(range.y)/25)*25+range.y[1],
                             by=25)
      }
      
      plotType(data.kk[,1], data.kk[,2], xlab=names.var[1], ylab=names.var[2],
               main=paste(title.pl, names.var[1], "vs",
                 names.var[2], sep=" "),
               x.grid=x.grid.CSPlot,
               y.grid=y.grid.CSPlot, hexbin.plotted=hexbin.CSPlot,
               hexbin.style=hexbin.style.CSPlot,
               n.hexbins=n.hexbins.CSPlot,
               image.col=image.col.CSPlot, numlev=numlev.CSPlot, xaxt=xaxt, yaxt=yaxt,...)
      
    } else { ## default plot
      if (is.null(xlimit)){
        xlimit <- range(data.kk[,1])
      }
      if (is.null(ylimit)){
        ylimit <- range(data.kk[,2])
      }
      plotType(data.kk[,1], data.kk[,2], xlab=names.var[1], ylab=names.var[2],
               main=paste(title.pl, names.var[1], "vs",
                 names.var[2], sep=" "), xlim=xlimit, ylim=ylimit,
               col=color.hist.plot, xaxt=xaxt, yaxt=yaxt,...)
    }
  }
}

==> rflowcyt_1.20.0.tar.gz: rflowcyt/R/plotvar.FCS.R <==
plotvar.FCS <- function(x,
                        varpos,
                        type=c("uni", "bi"),
                        plotType=c("hist", "ContourScatterPlot", "plot"),
                        names.var=NULL,
                        title.pl="",
                        xlimit=NULL,
                        ylimit=NULL,
                        plot.freq=TRUE,
                        color.hist.plot="white",
                        CSPlot=TRUE,
                        hexbin.CSPlot=TRUE,
                        hexbin.style.CSPlot=c("colorscale",
                          "lattice", "centroids",
                          "nested.lattice", "nested.centroids"),
                        n.hexbins.CSPlot=100,
                        x.grid.CSPlot=seq(0, 1025, by=25),
                        y.grid.CSPlot=seq(0, 1025, by=25),
                        image.col.CSPlot=heat.colors(2),
                        numlev.CSPlot=25,
                        xaxt="s",
                        yaxt="s",
                        MY.DEBUG=FALSE, ...) {
  
  ##
  ## input
  ##
  
  ## x    FCS object from read.FCS function
  ## type        type of cut/gating
  ##              uni  univariate graph
  ##              bi bivariate graph
  
  
  ## plotType    default is ContourScatterPlot, but can also be plot, hist, etc.
  ## varpos         the variable column position of the data being examined
  ##                or a vector of column postions
  
  ## names       a character vector of the names of the variables to be plotted
  ##                either one name or two names
  ## title       a string of the title of the graph
  ## xlimit      a vector denoting the range of the x (horizontal) axis
  ## ylimit      a vector denoting the range of the y (vertical) axis
  ## plot.freq   boolean; if true then the frequencies instead of the
  ##                relative frequencies (probabilities) are plotted (only if plotType=hist)
  
  ## CSPlot      a boolean of whether or not this is a ContourScatterPlot
  
  ## xgrid.CSPlot    a sequence denoting the grid marks
  ##                    for the x coordinate (for ContourScatterPlot ONLY!)
  ## ygrid.CSPlot    a sequence denoting the grid marks
  ##                     for the y coordinate (for ContourScatterPlot ONLY!)
  ## image.col.CSPlot  a color for the image (for ContourScatterPlot ONLY!)
  ## numlev.CSplot     number of levels for the ContourScatterPlot
  ## MY.DEBUG         boolean; if true then process statements are printed
  ##
  ## output
  ##
  ## a graph with the gates shown
  
  if (!checkvars(x, MY.DEBUG=MY.DEBUG)){
    x <- fixvars(x, MY.DEBUG=MY.DEBUG)
  }

 
  if (is.null(names.var)==TRUE) {
    names.var <- colnames(x@data)[varpos]
  }
            
  data.kk <- x@data[,varpos]
  
  ## type <- match.arg(type)
  if (length(varpos) %in% c(1,2)) {
    type <- c("uni", "bi")[length(varpos)]
  } else {
    stop("Input 'varpos' can only be of length 1 or 2")
  }
          
          
  plotType <- c("hist", "ContourScatterPlot", "plot")[length(varpos)]
  if (CSPlot==TRUE){
    plotType <- "ContourScatterPlot"
  } else {
    plotType <- "plot"
  }


  plotType <- get(plotType)
  if (type=="uni"){
     ##note this is NOT probability Binning, only a regular histogram, prob binning should be done only after gating
       
    if (is.null(xlimit)){
         
        xlimit <- range(data.kk)
    }
    
    if (is.null(ylimit)){
      hist(data.kk, xlab=names.var[1], ylab="frequency",
           main=paste(title.pl, names.var[1], sep=" "),
           freq=plot.freq,
           xlim=xlimit,
           col=color.hist.plot, xaxt=xaxt,
           yaxt=yaxt,...)
    } else {
      hist(data.kk, xlab=names.var[1], ylab="frequency",
           main=paste(title.pl, names.var[1], sep=" "),
           freq=plot.freq,
           xlim=xlimit, ylim=ylimit,
           col=color.hist.plot, xaxt=xaxt,
           yaxt=yaxt,...)
      
      
    }
    
  } else if (type=="bi"){
      if(CSPlot==TRUE){
          if (is.null(x.grid.CSPlot)){
              range.x <- range(data.kk[,1])
              x.grid.CSPlot <- seq(range.x[1],
                             ceiling(diff(range.x)/25)*25+range.x[1],
                             by=25)
          }
          if (is.null(y.grid.CSPlot)){
              range.y <- range(data.kk[,2])
              y.grid.CSPlot <- seq(range.y[1],
                             ceiling(diff(range.y)/25)*25+range.y[1],
                             by=25)
          }
          
          plotType(data.kk[,1], data.kk[,2], xlab=names.var[1], ylab=names.var[2],
               main=paste(title.pl, names.var[1], "vs",
                 names.var[2], sep=" "),lattice=FALSE,
               x.grid=x.grid.CSPlot,
              y.grid=y.grid.CSPlot, hexbin.plotted=hexbin.CSPlot,
                hexbin.style=hexbin.style.CSPlot,
                n.hexbins=n.hexbins.CSPlot, 
             image.col=image.col.CSPlot, numlev=numlev.CSPlot, xaxt=xaxt, yaxt=yaxt,...)
       
    } else { ## default plot
      if (is.null(xlimit)){
        xlimit <- range(data.kk[,1])
      }
      if (is.null(ylimit)){
        ylimit <- range(data.kk[,2])
      }
      plotType(data.kk[,1], data.kk[,2], xlab=names.var[1], ylab=names.var[2],
               main=paste(title.pl, names.var[1], "vs",
                 names.var[2], sep=" "), xlim=xlimit, ylim=ylimit,lattice=FALSE,
               col=color.hist.plot, xaxt=xaxt, yaxt=yaxt,...)
    }
  }
}
